@@ -19,9 +19,9 @@
 
 """Provides a SpeechServer factory for gnome-speech drivers."""
 
-__id__        = "$Id: gnomespeechfactory.py 1945 2007-01-19 21:32:18Z wwalker $"
-__version__   = "$Revision: 1945 $"
-__date__      = "$Date: 2007-01-19 16:32:18 -0500 (Fri, 19 Jan 2007) $"
+__id__        = "$Id: gnomespeechfactory.py 3114 2007-10-19 16:32:36Z wwalker $"
+__version__   = "$Revision: 3114 $"
+__date__      = "$Date: 2007-10-19 12:32:36 -0400 (Fri, 19 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -37,8 +37,8 @@ import threading
 import time
 
 import bonobo
+import ORBit
 
-import atspi
 import chnames
 import debug
 import orca_state
@@ -46,13 +46,12 @@ import punctuation_settings
 import settings
 import speech
 import speechserver
-import util
 
 from acss import ACSS
 
 from orca_i18n import _           # for gettext support
 
-atspi.ORBit.load_typelib('GNOME_Speech')
+ORBit.load_typelib('GNOME_Speech')
 import GNOME.Speech, GNOME__POA.Speech
 
 class _SayAll:
@@ -97,6 +96,8 @@ class _Speaker(GNOME__POA.Speech.SpeechCallback):
             callback.notify(type, id, offset)
 
     def say(self, text):
+        if isinstance(text, unicode):
+            text = text.encode("UTF-8")
         return self.gnome_speaker.say(text)
 
     def stop(self):
@@ -264,6 +265,8 @@ class SpeechServer(speechserver.SpeechServer):
         self.__gidleId       = 0
         self.__gidleLock     = threading.Lock()
         self.__lastResetTime = 0
+        self.__lastText      = None
+        self.textCharIndices = []
 
     def __getRate(self, speaker):
         """Gets the voice-independent ACSS rate value of a voice."""
@@ -474,38 +477,41 @@ class SpeechServer(speechserver.SpeechServer):
 
         # Added in the notify method below.
         #
-        # id     = the id of the utterance we sent to gnome-speech
+        # thisId = the id of the utterance we sent to gnome-speech
         # type   = the type of progress we're getting
         # offset = character offset into the utterance
         #
-        (id, type, offset) = self.__eventQueue.get()
+        (thisId, thisType, offset) = self.__eventQueue.get()
+
+        offset = self.__adjustTextCharIndex(offset)
 
         if self.__sayAll:
-            if self.__sayAll.idForCurrentContext == id:
+            if self.__sayAll.idForCurrentContext == thisId:
                 context = self.__sayAll.currentContext
-                if type == GNOME.Speech.speech_callback_speech_started:
+                if thisType == GNOME.Speech.speech_callback_speech_started:
                     context.currentOffset = context.startOffset
                     self.__sayAll.progressCallback(
                         self.__sayAll.currentContext,
                         speechserver.SayAllContext.PROGRESS)
-                elif type == GNOME.Speech.speech_callback_speech_progress:
+                elif thisType == GNOME.Speech.speech_callback_speech_progress:
                     context.currentOffset = context.startOffset + offset
                     self.__sayAll.progressCallback(
                         self.__sayAll.currentContext,
                         speechserver.SayAllContext.PROGRESS)
-                elif type == GNOME.Speech.speech_callback_speech_ended:
+                elif thisType == GNOME.Speech.speech_callback_speech_ended:
                     try:
-                        [self.__sayAll.currentContext, acss] = \
-                            self.__sayAll.utteranceIterator.next()
-                        debug.println(debug.LEVEL_INFO,
-                                      "SPEECH OUTPUT: '" \
-                                      + self.__sayAll.currentContext.utterance\
-                                      + "'")
-                        log.info("'%s'" \
-                                 % self.__sayAll.currentContext.utterance)
-                        self.__sayAll.idForCurrentContext = self.__speak(
-                            self.__sayAll.currentContext.utterance,
-                            acss)
+                        while True:
+                            [self.__sayAll.currentContext, acss] = \
+                                self.__sayAll.utteranceIterator.next()
+                            utterance = self.__sayAll.currentContext.utterance
+                            logLine = "SPEECH OUTPUT: '" + utterance + "'"
+                            debug.println(debug.LEVEL_INFO, logLine)
+                            log.info(logLine)
+                            if utterance and len(utterance)\
+                               and not utterance.isspace():
+                                self.__sayAll.idForCurrentContext = \
+                                    self.__speak(utterance, acss)
+                                break
                     except StopIteration:
                         self.__isSpeaking = False
                         context.currentOffset = context.endOffset
@@ -573,7 +579,6 @@ class SpeechServer(speechserver.SpeechServer):
                 families.append(speechserver.VoiceFamily(props))
         except:
             debug.printException(debug.LEVEL_SEVERE)
-            pass
 
         return families
 
@@ -637,6 +642,22 @@ class SpeechServer(speechserver.SpeechServer):
                 self.speak(text, acss, interrupt and (i == 0))
             i += 1
 
+    def __adjustTextCharIndex(self, offset):
+        """Get the original character index into the text string (before
+        the string was adjusted for verbalized punctuation.
+
+        Arguments:
+        - offset: character offset into text string
+
+        Returns the equivalent character index into the original text string.
+        """
+
+        for i in range(0, len(self.textCharIndices)):
+            if self.textCharIndices[i] >= offset:
+                break
+
+        return i
+
     def __addVerbalizedPunctuation(self, oldText):
         """Depending upon the users verbalized punctuation setting,
         adjust punctuation symbols in the given text to their pronounced
@@ -654,8 +675,12 @@ class SpeechServer(speechserver.SpeechServer):
         Returns a text string with the punctuation symbols adjusted accordingly.
         """
 
-        ## Replace ellipses (both manual and UTF-8) with "dot dot dot"
-        ##
+        # Translators: we replace the ellipses (both manual and UTF-8)
+        # with a spoken string.  The extra space you see at the beginning
+        # is because we need the speech synthesis engine to speak the
+        # new string well.  For example, "Open..." turns into
+        # "Open dot dot dot".
+        #
         oldText = oldText.replace("...", _(" dot dot dot"), 1)
         oldText = oldText.replace("\342\200\246",  _(" dot dot dot"), 1)
         oldText = oldText.decode("UTF-8")
@@ -673,9 +698,15 @@ class SpeechServer(speechserver.SpeechServer):
         if removeNewLines:
             oldText = oldText.replace("\n", "", 1)
 
+        # Used to keep a list of character offsets into the new text string,
+        # once it has been converted to use verbalized punctuation, one for
+        # each character in the original string.
+        #
+        self.textCharIndices = []
         style = settings.verbalizePunctuationStyle
         newText = ''
         for i in range(0, len(oldText)):
+            self.textCharIndices.append(len(newText))
             try:
                 level, action = \
                     punctuation_settings.getPunctuationInfo(oldText[i])
@@ -699,7 +730,11 @@ class SpeechServer(speechserver.SpeechServer):
                 # always speak it. See bug #392939.
                 #
                 prevCharMatches = nextCharMatches = False
-                currencySymbols = util.getUnicodeCurrencySymbols()
+                if orca_state.activeScript:
+                    currencySymbols = \
+                        orca_state.activeScript.getUnicodeCurrencySymbols()
+                if i == 0:
+                    prevCharMatches = True
                 if i > 0:
                     prevCharMatches = (oldText[i - 1] in string.whitespace)
                 if i < (len(oldText) - 1):
@@ -711,6 +746,13 @@ class SpeechServer(speechserver.SpeechServer):
                    prevCharMatches and nextCharMatches:
                     if isPrev:
                         newText += " "
+                    # Translators: this is to be sent to a speech synthesis
+                    # engine to prefix a negative number (e.g., "-56" turns
+                    # into "minus 56".  We cannot always be sure of the type
+                    # of the number (floating point, integer, mixed with other
+                    # odd characters, etc.), so we need to unfortunately
+                    # build up the utterance in this manner.
+                    #
                     newText += _("minus")
                 elif (len(oldText) == 1) or isSpecial or (style <= level):
                     if isPrev:
@@ -767,7 +809,8 @@ class SpeechServer(speechserver.SpeechServer):
             return -1
 
         text = self.__addVerbalizedPunctuation(text)
-        text = util.adjustForPronunciation(text)
+        if orca_state.activeScript and orca_state.usePronunciationDictionary:
+            text = orca_state.activeScript.adjustForPronunciation(text)
 
         try:
             # [[[TODO: WDW - back this stop out for now.  The problem is
@@ -823,9 +866,9 @@ class SpeechServer(speechserver.SpeechServer):
         """
         try:
             [context, acss] = utteranceIterator.next()
-            debug.println(debug.LEVEL_INFO,
-                          "SPEECH OUTPUT: '" + context.utterance + "'")
-            log.info("'%s'" % context.utterance)
+            logLine = "SPEECH OUTPUT: '" + context.utterance + "'"
+            debug.println(debug.LEVEL_INFO, logLine)
+            log.info(logLine)
             self.__sayAll = _SayAll(utteranceIterator,
                                     context,
                                     self.__speak(context.utterance, acss),
@@ -857,6 +900,9 @@ class SpeechServer(speechserver.SpeechServer):
             debug.println(debug.LEVEL_CONFIGURATION,
                           "speech.increaseSpeechPitch: pitch is now " \
                           " %d" % pitch)
+            # Translators: this is a short string saying that the speech
+            # synthesis engine is now speaking in a higher pitch.
+            #
             self.speak(_("higher."))
         except:
             debug.printException(debug.LEVEL_SEVERE)
@@ -885,6 +931,9 @@ class SpeechServer(speechserver.SpeechServer):
             debug.println(debug.LEVEL_CONFIGURATION,
                           "speech.decreaseSpeechPitch: pitch is now " \
                           " %d" % pitch)
+            # Translators: this is a short string saying that the speech
+            # synthesis engine is now speaking in a lower pitch.
+            #
             self.speak(_("lower."))
         except:
             debug.printException(debug.LEVEL_SEVERE)
@@ -910,6 +959,10 @@ class SpeechServer(speechserver.SpeechServer):
             debug.println(debug.LEVEL_CONFIGURATION,
                           "speech.increaseSpeechRate: rate is now " \
                           " %d" % rate)
+            # Translators: this is a short string saying that the speech
+            # synthesis engine is now speaking at a faster rate (words
+            # per minute).
+            #
             self.speak(_("faster."))
         except:
             debug.printException(debug.LEVEL_SEVERE)
@@ -940,6 +993,10 @@ class SpeechServer(speechserver.SpeechServer):
             debug.println(debug.LEVEL_CONFIGURATION,
                           "speech.decreaseSpeechRate: rate is now " \
                           " %d" % rate)
+            # Translators: this is a short string saying that the speech
+            # synthesis engine is now speaking at a slower rate (words
+            # per minute).
+            #
             self.speak(_("slower."))
         except:
             debug.printException(debug.LEVEL_SEVERE)
@@ -1005,4 +1062,3 @@ class SpeechServer(speechserver.SpeechServer):
                 except:
                     debug.printException(debug.LEVEL_SEVERE)
                     self.__driver = None
-                    pass
