@@ -23,13 +23,13 @@ MouseButtonEvent, MouseMotionEvent, and SpeechEvent), and also provides a
 InputEventHandler class.  It is intended that instances of InputEventHandler
 will be used which should be used to handle all input events."""
 
-__id__        = "$Id: input_event.py 1529 2006-10-05 16:31:04Z wwalker $"
-__version__   = "$Revision: 1529 $"
-__date__      = "$Date: 2006-10-05 12:31:04 -0400 (Thu, 05 Oct 2006) $"
+__id__        = "$Id: input_event.py 3099 2007-10-18 20:17:26Z shaeger $"
+__version__   = "$Revision: 3099 $"
+__date__      = "$Date: 2007-10-18 16:17:26 -0400 (Thu, 18 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import atspi
+import pyatspi
 import debug
 import settings
 import time
@@ -70,7 +70,7 @@ class KeyboardEvent(InputEvent):
         # mapping ASCII control characters to UTF-8.]]]
         #
         event_string = event.event_string
-        if (event.modifiers & (1 << atspi.Accessibility.MODIFIER_CONTROL)) \
+        if (event.modifiers & (1 << pyatspi.MODIFIER_CONTROL)) \
             and (not event.is_text) and (len(event_string) == 1):
             value = ord(event.event_string[0])
             if value < 32:
@@ -146,6 +146,10 @@ class InputEventHandler:
         self._description = description
         self._learnModeEnabled = learnModeEnabled
 
+    def __eq__(self, other):
+        """Compares one input handler to another."""
+        return (self._function == other._function)
+
     def processInputEvent(self, script, inputEvent):
         """Processes an input event.  If settings.learnModeEnabled is True,
         this will merely report the description of the input event to braille
@@ -180,3 +184,11 @@ class InputEventHandler:
                 debug.printException(debug.LEVEL_SEVERE)
 
         return consumed
+
+def keyEventToString(event):
+    return ("KEYEVENT: type=%d\n" % event.type) \
+        + ("          hw_code=%d\n" % event.hw_code) \
+        + ("          modifiers=%d\n" % event.modifiers) \
+        + ("          event_string=(%s)\n" % event.event_string) \
+        + ("          is_text=%s\n" % event.is_text) \
+        + ("          time=%f" % time.time())
