@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -20,10 +20,10 @@
 """Provides support for defining keybindings and matching them to input
 events."""
 
-__id__        = "$Id: keybindings.py 2191 2007-03-19 19:30:55Z richb $"
-__version__   = "$Revision: 2191 $"
-__date__      = "$Date: 2007-03-19 15:30:55 -0400 (Mon, 19 Mar 2007) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: keybindings.py 3092 2007-10-18 17:21:05Z shaeger $"
+__version__   = "$Revision: 3092 $"
+__date__      = "$Date: 2007-10-18 13:21:05 -0400 (Thu, 18 Oct 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 try:
@@ -33,18 +33,63 @@ try:
     # the desktop is not running.
     #
     import gtk
-except:
+except ImportError:
     pass
 
-import atspi
+import pyatspi
 import debug
 import settings
 
 from orca_i18n import _           # for gettext support
 
+_keysymsCache = {}
 _keycodeCache = {}
 
-def _getKeycode(keysym):
+def getAllKeysyms(keysym):
+    """Given a keysym, find all other keysyms associated with the key
+    that is mapped to the given keysym.  This allows us, for example,
+    to determine that the key bound to KP_Insert is also bound to KP_0."""
+
+    if not _keysymsCache.has_key(keysym):
+        # The keysym itself is always part of the list.
+        #
+        _keysymsCache[keysym] = [keysym]
+
+        # Find the numerical value of the keysym
+        #
+        keyval = gtk.gdk.keyval_from_name(keysym)
+
+        if keyval != 0:
+            # Find the keycodes for the keysym.  Since a keysym
+            # can be associated with more than one key, we'll shoot
+            # for the keysym that's in group 0, regardless of shift
+            # level (each entry is of the form [keycode, group,
+            # level]).
+            #
+            keymap = gtk.gdk.keymap_get_default()
+            entries = keymap.get_entries_for_keyval(keyval)
+            keycode = 0
+            if entries:
+                for entry in entries:
+                    if entry[1] == 0:  # group = 0
+                        keycode = entry[0]
+                        break
+
+            # Find the keysyms bound to the keycode.  These are what
+            # we are looking for.
+            #
+            if keycode != 0:
+                entries = keymap.get_entries_for_keycode(keycode)
+                if entries:
+                    for entry in entries:
+                        keyval = entry[0]
+                        name = gtk.gdk.keyval_name(keyval)
+                        if name and (name != keysym):
+                            _keysymsCache[keysym].append(name)
+
+    return _keysymsCache[keysym]
+
+def getKeycode(keysym):
     """Converts an XKeysym string (e.g., 'KP_Enter') to a keycode that
     should match the event.hw_code for key events.
 
@@ -105,23 +150,44 @@ def getModifierNames(mods):
     text = ""
     if mods & (1 << settings.MODIFIER_ORCA):
         text += _("Orca") + "+"
-    #if mods & (1 << atspi.Accessibility.MODIFIER_NUMLOCK):
+    #if mods & (1 << pyatspi.MODIFIER_NUMLOCK):
     #    text += _("Num_Lock") + "+"
     if mods & 128:
+        # Translators: this is presented in a GUI to represent the
+        # "right alt" modifier.
+        #
         text += _("Alt_R") + "+"
-    if mods & (1 << atspi.Accessibility.MODIFIER_META3):
+    if mods & (1 << pyatspi.MODIFIER_META3):
+        # Translators: this is presented in a GUI to represent the
+        # "super" modifier.
+        #
         text += _("Super") + "+"
-    if mods & (1 << atspi.Accessibility.MODIFIER_META2):
+    if mods & (1 << pyatspi.MODIFIER_META2):
+        # Translators: this is presented in a GUI to represent the
+        # "meta 2" modifier.
+        #
         text += _("Meta2") + "+"
-    #if mods & (1 << atspi.Accessibility.MODIFIER_META):
+    #if mods & (1 << pyatspi.MODIFIER_META):
     #    text += _("Meta") + "+"
-    if mods & (1 << atspi.Accessibility.MODIFIER_ALT):
+    if mods & (1 << pyatspi.MODIFIER_ALT):
+        # Translators: this is presented in a GUI to represent the
+        # "left alt" modifier.
+        #
         text += _("Alt_L") + "+"
-    if mods & (1 << atspi.Accessibility.MODIFIER_CONTROL):
+    if mods & (1 << pyatspi.MODIFIER_CONTROL):
+        # Translators: this is presented in a GUI to represent the
+        # "control" modifier.
+        #
         text += _("Ctrl") + "+"
-    if mods & (1 << atspi.Accessibility.MODIFIER_SHIFTLOCK):
+    if mods & (1 << pyatspi.MODIFIER_SHIFTLOCK):
+        # Translators: this is presented in a GUI to represent the
+        # "caps lock" modifier.
+        #
         text += _("Caps_Lock") + "+"
-    if mods & (1 << atspi.Accessibility.MODIFIER_SHIFT):
+    if mods & (1 << pyatspi.MODIFIER_SHIFT):
+        # Translators: this is presented in a GUI to represent the
+        # "shift " modifier.
+        #
         text += _("Shift") + "+"
     return text
 
@@ -138,10 +204,10 @@ class KeyBinding:
           from /usr/include/X11/keysymdef.h with the preceding 'XK_'
           removed (e.g., XK_KP_Enter becomes the string 'KP_Enter').
         - modifier_mask: bit mask where a set bit tells us what modifiers
-          we care about (see atspi.Accessibility.MODIFIER_*)
+          we care about (see pyatspi.MODIFIER_*)
         - modifiers: the state the modifiers we care about must be in for
           this key binding to match an input event (see also
-          atspi.Accessibility.MODIFIER_*)
+          pyatspi.MODIFIER_*)
         - handler: the InputEventHandler for this key binding
         """
 
@@ -161,7 +227,7 @@ class KeyBinding:
         # keybindings in the user's preferences file.
         #
         if not self.keycode:
-            self.keycode = _getKeycode(self.keysymstring)
+            self.keycode = getKeycode(self.keysymstring)
 
         if self.keycode == keycode:
             result = modifiers & self.modifier_mask
@@ -176,6 +242,16 @@ class KeyBindings:
     def __init__(self):
         self.keyBindings = []
 
+    def __str__(self):
+        result = "[\n"
+        for keyBinding in self.keyBindings:
+            result += "  [%x %x %s %s]\n" % (keyBinding.modifier_mask,
+                                             keyBinding.modifiers,
+                                             keyBinding.keysymstring,
+                                             keyBinding.handler._description)
+        result += "]"
+        return result
+    
     def add(self, keyBinding):
         """Adds the given KeyBinding instance to this set of keybindings.
         """
@@ -258,7 +334,7 @@ class KeyBindings:
         handler = self.getInputHandler(keyboardEvent)
         if handler:
             consumed = True
-            if keyboardEvent.type == atspi.Accessibility.KEY_PRESSED_EVENT:
+            if keyboardEvent.type == pyatspi.KEY_PRESSED_EVENT:
                 try:
                     handler.processInputEvent(script, keyboardEvent)
                 except:
