@@ -21,18 +21,17 @@
 of manipulating text - both the user and the system put text into the
 system and we try to determine which was which and why."""
 
-__id__        = "$Id: gnome-terminal.py 2371 2007-05-11 15:28:14Z richb $"
-__version__   = "$Revision: 2371 $"
-__date__      = "$Date: 2007-05-11 11:28:14 -0400 (Fri, 11 May 2007) $"
+__id__        = "$Id: gnome-terminal.py 3153 2007-10-22 19:18:04Z eitani $"
+__version__   = "$Revision: 3153 $"
+__date__      = "$Date: 2007-10-22 15:18:04 -0400 (Mon, 22 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-import orca.atspi as atspi
-import orca.debug as debug
+import pyatspi
+
 import orca.default as default
 import orca.input_event as input_event
 import orca.orca_state as orca_state
-import orca.rolenames as rolenames
 import orca.settings as settings
 import orca.speech as speech
 
@@ -89,7 +88,7 @@ class Script(default.Script):
         # We only do special things when people press backspace
         # in terminals.
         #
-        if (event.source.role != rolenames.ROLE_TERMINAL) \
+        if (event.source.getRole() != pyatspi.ROLE_TERMINAL) \
             or (event_string != "BackSpace"):
             default.Script.onTextDeleted(self, event)
             return
@@ -121,7 +120,7 @@ class Script(default.Script):
 
         # We only do special things for terminals.
         #
-        if event.source.role != rolenames.ROLE_TERMINAL:
+        if event.source.getRole() != pyatspi.ROLE_TERMINAL:
             default.Script.onTextInserted(self, event)
             return
 
@@ -155,7 +154,7 @@ class Script(default.Script):
             keyString = orca_state.lastNonModifierKeyEvent.event_string
 
             controlPressed = orca_state.lastInputEvent.modifiers \
-                             & (1 << atspi.Accessibility.MODIFIER_CONTROL)
+                             & (1 << pyatspi.MODIFIER_CONTROL)
 
             if (keyString == "Delete") or (keyString == "BackSpace"):
                 return
@@ -186,11 +185,11 @@ class Script(default.Script):
             # compressed string is (we choose 5 here), then output that.
             #
             wasCommand = orca_state.lastInputEvent.modifiers \
-                         & (1 << atspi.Accessibility.MODIFIER_CONTROL \
-                            | 1 << atspi.Accessibility.MODIFIER_ALT \
-                            | 1 << atspi.Accessibility.MODIFIER_META \
-                            | 1 << atspi.Accessibility.MODIFIER_META2 \
-                            | 1 << atspi.Accessibility.MODIFIER_META3)
+                         & (1 << pyatspi.MODIFIER_CONTROL \
+                            | 1 << pyatspi.MODIFIER_ALT \
+                            | 1 << pyatspi.MODIFIER_META \
+                            | 1 << pyatspi.MODIFIER_META2 \
+                            | 1 << pyatspi.MODIFIER_META3)
             wasCommand = wasCommand \
                          or (keyString == "Return") \
                          or (keyString == "Tab")
