@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 2469 2007-06-12 20:19:09Z richb $"
-__version__   = "$Revision: 2469 $"
-__date__      = "$Date: 2007-06-12 16:19:09 -0400 (Tue, 12 Jun 2007) $"
+__id__        = "$Id: settings.py 3090 2007-10-18 15:51:40Z richb $"
+__version__   = "$Revision: 3090 $"
+__date__      = "$Date: 2007-10-18 11:51:40 -0400 (Thu, 18 Oct 2007) $"
 __copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -103,6 +103,7 @@ userCustomizableSettings = [
     "enableBrailleGrouping",
     "brailleVerbosityLevel",
     "brailleRolenameStyle",
+    "brailleSelectorIndicator",
     "enableBrailleMonitor",
     "enableMagnifier",
     "enableMagCursor",
@@ -129,7 +130,11 @@ userCustomizableSettings = [
     "sayAllStyle",
     "keyboardLayout",
     "speakBlankLines",
-    "enabledTextAttributes",
+    "enabledSpokenTextAttributes",
+    "enabledBrailledTextAttributes",
+    "textAttributesBrailleIndicator",
+    "enableProgressBarUpdates",
+    "progressBarUpdateInterval"
 ]
 
 # The name of the module that hold the user interface for the main window
@@ -142,9 +147,9 @@ mainWindowModule = "orca_gui_main"
 # Orca preferences.  Each module is expected to have the method,
 # showPreferencesUI, which will prompt the user for preferences.
 #
-guiPreferencesModule    = "orca_gui_prefs"
-consolePreferencesModule= "orca_console_prefs"
-appGuiPreferencesModule = "app_gui_prefs"
+guiPreferencesModule     = "orca_gui_prefs"
+consolePreferencesModule = "orca_console_prefs"
+appGuiPreferencesModule  = "app_gui_prefs"
 
 # The name of the module that hold the user interface for quitting Orca.
 # This module is expected to have the method, showQuitUI, which will
@@ -189,6 +194,16 @@ BRAILLE_ROLENAME_STYLE_SHORT = 0 # three letter abbreviations
 BRAILLE_ROLENAME_STYLE_LONG  = 1 # full rolename
 brailleRolenameStyle    = BRAILLE_ROLENAME_STYLE_LONG
 
+# Braille Selection Indicator (see brailleSelectorIndicator).
+# The values represent the character to be used in the attrOr
+# field of brlAPI's writeStruct.
+#
+BRAILLE_SEL_NONE = '\x00' # 00000000
+BRAILLE_SEL_7    = '\x40' # 01000000
+BRAILLE_SEL_8    = '\x80' # 10000000
+BRAILLE_SEL_BOTH = '\xc0' # 11000000
+brailleSelectorIndicator = BRAILLE_SEL_BOTH
+
 # Speech punctuation levels (see verbalizePunctuationStyle).
 #
 PUNCTUATION_STYLE_NONE = 3
@@ -220,6 +235,11 @@ speechPitchDelta        = 0.5
 #
 httpServerPort          = 20433
 
+# The number of attempts to retry setting up an HTTP server
+# connection (each time incrementing the port number by 1).
+#
+maxHttpServerRetries   = 20
+
 # If True, enable speech.
 #
 enableSpeech            = True
@@ -232,7 +252,9 @@ silenceSpeech           = False
 # Settings that apply to the particular speech engine to
 # use as well details on the default voices to use.
 #
-speechFactoryModules    = ["espeechfactory","gnomespeechfactory","speechdispatcherfactory"]
+speechFactoryModules    = ["espeechfactory", \
+                           "gnomespeechfactory", \
+                           "speechdispatcherfactory"]
 speechServerFactory     = "gnomespeechfactory"
 speechServerInfo        = None # None means let the factory decide.
 
@@ -242,7 +264,7 @@ HYPERLINK_VOICE         = "hyperlink"
 
 voices = {
     DEFAULT_VOICE   : ACSS({}),
-    UPPERCASE_VOICE : ACSS({ACSS.AVERAGE_PITCH : 6}),
+    UPPERCASE_VOICE : ACSS({ACSS.AVERAGE_PITCH : 5.6}),
     HYPERLINK_VOICE : ACSS({})
 }
 
@@ -398,6 +420,15 @@ speakBlankLines         = True
 #
 readTableCellRow    = True
 
+# If True, enable speaking of progress bar updates.
+#
+enableProgressBarUpdates = False
+
+# The interval (in seconds) between speaking progress bar updates. A value
+# of zero means that progress bar updates should not be spoken at all.
+#
+progressBarUpdateInterval = 10
+
 # The complete list of possible text attributes.
 #
 allTextAttributes = "bg-color:; bg-full-height:; bg-stipple:; direction:; editable:; family-name:; fg-color:; fg-stipple:; font-effect:none; indent:0; invisible:; justification:left; language:; left-margin:; line-height:100%; paragraph-style:Default; pixels-above-lines:; pixels-below-lines:; pixels-inside-wrap:; right-margin:; rise:; scale:; size:; stretch:; strikethrough:false; style:normal; text-decoration:none; text-rotation:0; text-shadow:none; underline:none; variant:; vertical-align:baseline; weight:400; wrap-mode:; writing-mode:lr-tb;"
@@ -410,7 +441,27 @@ allTextAttributes = "bg-color:; bg-full-height:; bg-stipple:; direction:; editab
 # it won't be spoken. If no value part is given, then that attribute will
 # always be spoken.
 
-enabledTextAttributes = "size:; family-name:; weight:400; indent:0; underline:none; strikethrough:false; justification:left; style:normal;"
+enabledSpokenTextAttributes = "size:; family-name:; weight:400; indent:0; underline:none; strikethrough:false; justification:left; style:normal;"
+
+# The default set of text attributes to be brailled for the user. Specific
+# application scripts (or individual users can override these values if
+# so desired. Each of these text attributes is of the form <key>:<value>;
+# The <value> part will be the "default" value for that attribute. In
+# other words, if the attribute for a given piece of text has that value,
+# it won't be spoken. If no value part is given, then that attribute will
+# always be brailled.
+
+enabledBrailledTextAttributes = "size:; family-name:; weight:400; indent:0; underline:none; strikethrough:false; justification:left; style:normal;"
+
+# Text Attributes Braille Indicator (see textAttributesBrailleIndicator).
+# The values represent the character to be used in the attrOr
+# field of brlAPI's writeStruct.
+#
+TEXT_ATTR_BRAILLE_NONE = '\x00' # 00000000
+TEXT_ATTR_BRAILLE_7    = '\x40' # 01000000
+TEXT_ATTR_BRAILLE_8    = '\x80' # 10000000
+TEXT_ATTR_BRAILLE_BOTH = '\xc0' # 11000000
+textAttributesBrailleIndicator = TEXT_ATTR_BRAILLE_NONE
 
 # The limit to enable a repeat character count to be spoken.
 # If set to 0, then there will be no repeat character count.
@@ -459,13 +510,23 @@ learnModeEnabled        = False
 #
 userPrefsDir = os.path.join(os.environ["HOME"], ".orca")
 
+# Assists with dealing with CORBA COMM_FAILURES.  A failure doesn't
+# always mean an object disappeared - there just might be a network
+# glitch.  So, on COMM_FAILURES, we might retry a few times before
+# giving up on an object.  This might need to be overridden by the
+# script.
+#
+commFailureWaitTime = 0.1
+commFailureAttemptLimit = 5
+
 # If non-zero, we use time.sleep() in various places to attempt to
 # free up the global interpreter lock.  Take a look at the following
 # URLs for more information:
 #
 # http://mail.python.org/pipermail/python-list/2002-October/126632.html
 # http://twistedmatrix.com/pipermail/twisted-python/2005-July/011052.html
-# http://www.pyzine.com/Issue001/Section_Articles/article_ThreadingGlobalInterpreter.html
+# http://www.pyzine.com/Issue001/Section_Articles/ \
+#                                 article_ThreadingGlobalInterpreter.html
 #
 gilSleepTime            = 0.00001
 
@@ -478,6 +539,12 @@ useBlockPreventor       = False
 #
 useBonoboMain           = True
 
+# If True, we handle events asynchronously - our normal mode of
+# queueing events and processing them later on the gidle thread.
+# If False, we handle events immediately - helpful for testing.
+#
+asyncMode               = True
+
 # If True, we output debug information for the event queue.  We
 # use this in addition to log level to prevent debug logic from
 # bogging down event handling.
@@ -543,6 +610,11 @@ def setGKSUGrabDisabled(disable):
 def overrideKeyBindings(script, keyBindings):
     return keyBindings
 
+# Allow for user customization of pronunciations.
+#
+def overridePronunciations(script, pronunciations):
+    return pronunciations
+
 # Which packages to search, and the order in which to search,
 # for application settings.  These packages are expected to be on
 # the PYTHONPATH and/or subpackages of the "orca" package.
@@ -622,6 +694,11 @@ setScriptMapping(re.compile(_('[\S\s]*StarOffice[\s\S]*')), "StarOffice")
 #
 setScriptMapping(re.compile(_('soffice.bin')), "StarOffice")
 
+# Translators: see the regular expression note above.  This is for
+# OpenOffice and StarOffice.
+#
+setScriptMapping(re.compile(_('soffice')), "StarOffice")
+
 # Translators: see the regular expression note above.  This is for the
 # Evolution mail application.
 #
@@ -664,3 +741,12 @@ setScriptMapping(re.compile(_('bug-buddy')), "gnome_segv2")
 # the underlying terminal support in gnome-terminal.
 #
 setScriptMapping(re.compile(_('vte')), "gnome-terminal")
+
+# Translators: see the regular expression note above.  This is for
+# supporting pidgin, which is the new name for gaim.
+#
+setScriptMapping(re.compile(_('pidgin')), "gaim")
+
+# Show deprecated messeges in debug output.
+# Set this to True to help find potential pyatspi porting problems
+deprecatedMessages = False
